==> core-1.0.0.tgz: package/lib/class-names/textarea-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiComponentProps } from '../ui-component-props/ui-component-props';
export const textareaClassNamesConfig = {
    prefix: 'cck-textarea',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-textarea'
            ],
            description: 'It will add to the host element of textarea component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-textarea--disabled'
            ],
            description: 'It will add to the host element of textarea component, the component is disabled'
        },
        autoResize: {
            name: 'Host Element',
            selectors: [
                'cck-textarea--auto-resize'
            ],
            description: 'It will add to the host element of textarea component, the the height of textarea will automatically change base on content'
        }
    }
};
export function getTextareaClassNames(componentProps, uiComponentsConfig) {
    const options = {
        componentName: 'textarea',
        componentProps,
        uiComponentsConfig
    };
    validateUiComponentProps(options);
    return {
        host: [
            ...textareaClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(textareaClassNamesConfig.prefix, options)
        ],
        disabled: [
            ...textareaClassNamesConfig.elements.disabled.selectors
        ],
        autoResize: [
            ...textareaClassNamesConfig.elements.autoResize.selectors
        ]
    };
}

==> core-1.1.0.tgz: package/lib/class-names/textarea-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiBaseComponentProps } from '../ui-component-props/ui-component-props';
export const textareaClassNamesConfig = {
    prefix: 'cck-textarea',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-textarea'
            ],
            description: 'It will add to the host element of textarea component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-textarea--disabled'
            ],
            description: 'It will add to the host element of textarea component, the component is disabled'
        },
        autoResize: {
            name: 'Host Element',
            selectors: [
                'cck-textarea--auto-resize'
            ],
            description: 'It will add to the host element of textarea component, the the height of textarea will automatically change base on content'
        }
    }
};
export function getTextareaClassNames(componentProps, themeConfig) {
    const options = {
        componentName: 'textarea',
        componentProps,
        themeConfig
    };
    validateUiBaseComponentProps(options);
    return {
        host: [
            ...textareaClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(textareaClassNamesConfig.prefix, options)
        ].join(' '),
        disabled: [
            ...textareaClassNamesConfig.elements.disabled.selectors
        ].join(' '),
        autoResize: [
            ...textareaClassNamesConfig.elements.autoResize.selectors
        ].join(' ')
    };
}
